@@ -10,7 +10,7 @@ logger = logging.getLogger(__name__)
 def gyro_fix(ev: Event, rate: int = 65):
     g = None
     try:
-        g = ForcedSampler(["gyro_3d"], False)
+        g = ForcedSampler(["gyro_3d"], True)
         g.open()
         while not ev.is_set():
             g.sample()
@@ -18,11 +18,12 @@ def gyro_fix(ev: Event, rate: int = 65):
     except KeyboardInterrupt:
         raise
     except Exception as e:
-        logger.warn(f"Gyro fix failed with error:{e}\n")
+        logger.warning(f"Gyro fix failed with error:{e}\n")
     finally:
         if g:
             g.close()
 
+
 class GyroFixer:
     def __init__(self, rate: int = 65) -> None:
         self.rate = rate
