@@ -72,9 +72,12 @@ class NumericalSetting(TypedDict):
     tags: Sequence[str]
     title: str
     hint: str | None
+    unit: str | None
 
     min: float | None
     max: float | None
+    smin: int | None
+    smax: int | None
     step: int | None
 
     default: float | None
@@ -87,9 +90,12 @@ class IntegerSetting(TypedDict):
     tags: Sequence[str]
     title: str
     hint: str | None
+    unit: str | None
 
     min: int | None
     max: int | None
+    smin: int | None
+    smax: int | None
     step: int | None
 
     default: int | None
@@ -284,8 +290,8 @@ DEFAULT_TAGS = {
 TYPE_TAGS = {
     "multiple": {"options": {}},
     "discrete": {"options": []},
-    "int": {"min": None, "max": None, "step": None},
-    "float": {"min": None, "max": None, "step": None},
+    "int": {"min": None, "max": None, "step": None, "unit": None, "smin": None, "smax": None},
+    "float": {"min": None, "max": None, "step": None, "unit": None, "smin": None, "smax": None},
     "custom": {"config": None},
 }
 
@@ -308,7 +314,7 @@ def merge_reduce(
                     if k in new_children:
                         new_children[k] = merge_reduce(new_children[k], v)  # type: ignore
                     else:
-                        new_children[k] = v
+                        new_children[k] = merge_reduce(v)  # type: ignore
                 s["children"] = new_children
             case "mode":
                 new_children = dict(a.get("modes", {}))
@@ -316,7 +322,7 @@ def merge_reduce(
                     if k in new_children:
                         new_children[k] = merge_reduce(new_children[k], v)  # type: ignore
                     else:
-                        new_children[k] = v
+                        new_children[k] = merge_reduce(v)  # type: ignore
                 s["modes"] = new_children
     else:
         if a.get("type", None) == "container":
@@ -653,9 +659,9 @@ def load_profile_yaml(fn: str):
 
 
 def get_settings_hash(set: HHDSettings):
-    import hashlib
+    import hashlib, json
 
-    return hashlib.md5(dump_comment(set).encode()).hexdigest()[:8]
+    return hashlib.md5(json.dumps(set).encode()).hexdigest()[:8]
 
 
 def unravel(d: Setting | Container | Mode, prev: Sequence[str], out: MutableMapping):
